@@ -3,6 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -10,76 +12,71 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/usr/pkg/bin',
- 'BINLIBDEST': '/usr/pkg/lib/python3.9',
- 'BLDLIBRARY': '-L. -lpython3.9',
- 'BLDSHARED': 'cc -shared -L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 '
-              '-Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'BINDIR': '/2022Q3/bin',
+ 'BINLIBDEST': '/2022Q3/lib/python3.10',
+ 'BLDLIBRARY': '-L. -lpython3.10',
+ 'BLDSHARED': 'cc -pthread -shared -L. -Wl,-zrelro -L/2022Q3/lib '
+              '-Wl,-R/2022Q3/lib -Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-unknown-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'cc',
+ 'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/usr/pkg/include -I/usr/pkg/include/ncurses '
-           '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-           '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-           '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-           '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-           '-I/usr/pkg/include/db4',
+           '-I/usr/include -I/2022Q3/include -I/2022Q3/include/ncurses '
+           '-I/2022Q3/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+           '-I/2022Q3/include -I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
+           '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+           '-I/2022Q3/include/ncurses -I/2022Q3/include/db4',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-                     '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                     '-I/usr/pkg/include/db4',
+ 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                     '-I/2022Q3/include/ncurses -I/2022Q3/include/db4',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include '
-                       '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
- 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-                      '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/2022Q3/include '
+                       '-I/2022Q3/include/ncurses -I/2022Q3/include/db4',
+ 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr/pkg' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/2022Q3' "
                 "'--with-system-ffi' '--without-ensurepip' "
-                "'--without-pymalloc' '--prefix=/usr/pkg' "
+                "'--without-pymalloc' '--prefix=/2022Q3' "
                 "'--build=x86_64-unknown-linux' '--host=x86_64-unknown-linux' "
-                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
+                "'--mandir=/2022Q3/man' '--enable-option-checking=yes' "
                 "'build_alias=x86_64-unknown-linux' "
                 "'host_alias=x86_64-unknown-linux' 'CC=cc' 'CFLAGS=-O2 "
-                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                "-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4' "
-                "'LDFLAGS=-Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 "
-                "-L/usr/pkg/lib -Wl,-R/usr/pkg/lib' 'LIBS=' "
-                "'CPPFLAGS=-I/usr/include -I/usr/pkg/include "
-                "-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4' "
-                "'PKG_CONFIG=/usr/pkgsrc/lang/python39/work/.tools/bin/pkg-config' "
+                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                "-I/2022Q3/include/ncurses -I/2022Q3/include/db4' "
+                "'LDFLAGS=-Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/2022Q3/include "
+                "-I/2022Q3/include/ncurses -I/2022Q3/include/db4' "
+                "'PKG_CONFIG=/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python39/work/.buildlink/lib64/pkgconfig:/usr/pkgsrc/lang/python39/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python39/work/.buildlink/share/pkgconfig'",
- 'CONFINCLUDEDIR': '/usr/pkg/include',
- 'CONFINCLUDEPY': '/usr/pkg/include/python3.9',
+                "'PKG_CONFIG_LIBDIR=/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/.buildlink/lib64/pkgconfig:/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/.buildlink/lib/pkgconfig:/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/.buildlink/share/pkgconfig'",
+ 'CONFINCLUDEDIR': '/2022Q3/include',
+ 'CONFINCLUDEPY': '/2022Q3/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/pkgsrc/lang/python39/work/Python-3.9.14/coverage.info',
- 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python39/work/Python-3.9.14/lcov-report',
+ 'COVERAGE_INFO': '/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7/coverage.info',
+ 'COVERAGE_REPORT': '/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-             '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -I/usr/include '
-             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-             '-I/usr/pkg/include/db4',
- 'CXX': 'c++',
- 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.9 '
-             '/usr/pkg/lib/python3.9/lib-dynload',
- 'DESTLIB': '/usr/pkg/lib/python3.9',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q3/include '
+             '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -I/usr/include '
+             '-I/2022Q3/include -I/2022Q3/include/ncurses '
+             '-I/2022Q3/include/db4',
+ 'CXX': 'c++ -pthread',
+ 'DESTDIRS': '/2022Q3 /2022Q3/lib /2022Q3/lib/python3.10 '
+             '/2022Q3/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/2022Q3/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/pkg/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/2022Q3/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -101,6 +98,7 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
@@ -143,6 +141,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -195,6 +194,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -433,6 +433,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -441,7 +442,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -469,6 +469,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -529,6 +530,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -540,49 +542,47 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
-                   '/usr/pkg/include/python3.9 /usr/pkg/include/python3.9',
- 'INCLUDEDIR': '/usr/pkg/include',
- 'INCLUDEPY': '/usr/pkg/include/python3.9',
- 'INSTALL': '/usr/bin/install -c -o root -g root',
- 'INSTALL_DATA': '/usr/bin/install -c -o root -g root -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g root -m 755',
- 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g root -m 755',
- 'INSTALL_SHARED': '/usr/bin/install -c -o root -g root -m 755',
- 'INSTSONAME': 'libpython3.9.so.1.0',
+ 'INCLDIRSTOMAKE': '/2022Q3/include /2022Q3/include /2022Q3/include/python3.10 '
+                   '/2022Q3/include/python3.10',
+ 'INCLUDEDIR': '/2022Q3/include',
+ 'INCLUDEPY': '/2022Q3/include/python3.10',
+ 'INSTALL': '/bin/install -c -o root -g root',
+ 'INSTALL_DATA': '/bin/install -c -o root -g root -m 644',
+ 'INSTALL_PROGRAM': '/bin/install -c -s -o root -g root -m 755',
+ 'INSTALL_SCRIPT': '/bin/install -c -o root -g root -m 755',
+ 'INSTALL_SHARED': '/bin/install -c -o root -g root -m 755',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
-            '-Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-            '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'LDCXXSHARED': 'c++ -pthread -shared',
+ 'LDFLAGS': '-L. -Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib -Wl,-zrelro '
+            '-L/2022Q3/lib -Wl,-R/2022Q3/lib',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.9.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -shared -L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 '
-             '-Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
- 'LDVERSION': '3.9',
+ 'LDSHARED': 'cc -pthread -shared -L. -Wl,-zrelro -L/2022Q3/lib '
+             '-Wl,-R/2022Q3/lib -Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/usr/pkg/lib/python3.9',
- 'LIBDIR': '/usr/pkg/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
+ 'LIBDEST': '/2022Q3/lib/python3.10',
+ 'LIBDIR': '/2022Q3/lib',
+ 'LIBFFI_INCLUDEDIR': '/2022Q3/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/usr/pkg/lib/pkgconfig',
- 'LIBPL': '/usr/pkg/lib/python3.9/config-3.9',
+ 'LIBPC': '/2022Q3/lib/pkgconfig',
+ 'LIBPL': '/2022Q3/lib/python3.10/config-3.10',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lintl -ldl  -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'cc',
+ 'LIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
+ 'LIBSUBDIRS': 'asyncio \\',
+ 'LINKCC': 'cc -pthread',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -593,18 +593,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/pkg/lib/python3.9',
+ 'MACHDESTLIB': '/2022Q3/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'cc',
+ 'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/usr/pkg/man',
+ 'MANDIR': '/2022Q3/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
+                   '_tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -617,19 +617,20 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-linux-gnu\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/usr/pkg/include',
- 'OPENSSL_LDFLAGS': '-L/usr/pkg/lib',
+ 'OPENSSL_INCLUDES': '-I/2022Q3/include',
+ 'OPENSSL_LDFLAGS': '-L/2022Q3/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
+ 'OPENSSL_RPATH': '',
+ 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+        '-I/2022Q3/include/ncurses -I/2022Q3/include/db4',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -638,8 +639,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
-                'Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '',
@@ -647,7 +647,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -660,87 +660,83 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/usr/pkg/include '
-                             '-I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/usr/pkg/include '
-                             '-I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -std=gnu99 -Wextra '
+                             '-I/2022Q3/include -I/2022Q3/include/ncurses '
+                             '-I/2022Q3/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/2022Q3/include '
+                             '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
+                             '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+                             '-I/2022Q3/include -I/2022Q3/include/ncurses '
+                             '-I/2022Q3/include/db4 -std=gnu99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include -I/usr/pkg/include '
-                             '-I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -I/usr/include '
-                             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                             '-I/usr/pkg/include/db4 -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-I./Include -I/usr/include -I/2022Q3/include '
+                             '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
+                             '-I/usr/include -I/2022Q3/include '
+                             '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
+                             '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+              '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+              '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+              '-I/2022Q3/include/ncurses -I/2022Q3/include/db4',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
-                   '-std=gnu99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                   '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                   '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                   '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -std=gnu99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                   '-I/usr/pkg/include/db4 -I/usr/include -I/usr/pkg/include '
-                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -fPIC '
+                   '-I/2022Q3/include -I/2022Q3/include/ncurses '
+                   '-I/2022Q3/include/db4 -I/usr/include -I/2022Q3/include '
+                   '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-                    '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro '
-                    '-L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
-                    '-Wl,-R/usr/pkg/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-                '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
-                '-I/usr/include -I/usr/pkg/include -I/usr/pkg/include/ncurses '
-                '-I/usr/pkg/include/db4',
+ 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib '
+                    '-Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q3/include '
+                '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
+                '-I/usr/include -I/2022Q3/include -I/2022Q3/include/ncurses '
+                '-I/2022Q3/include/db4',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
-               '-Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
-               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/2022Q3/lib -Wl,-R/2022Q3/lib -Wl,-zrelro '
+               '-L/2022Q3/lib -Wl,-R/2022Q3/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                        '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                        '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q3/include '
+                        '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
                         '-std=gnu99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
-                        '-I/usr/include -I/usr/pkg/include '
-                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
-                        '-fPIC',
+                        '-I./Include -I/usr/include -I/2022Q3/include '
+                        '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 '
+                        '-I/usr/include -I/2022Q3/include '
+                        '-I/2022Q3/include/ncurses -I/2022Q3/include/db4 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -749,13 +745,13 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python39/work/Python-3.9.14',
- 'SCRIPTDIR': '/usr/pkg/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7:/pkg/lib:/pkg/lib/nss:/pkg/lib/nspr',
+ 'SCRIPTDIR': '/2022Q3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lintl -ldl  -lm',
+ 'SHLIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 0,
+ 'SHM_NEEDS_LIBRT': 1,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -776,9 +772,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-39-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-310-x86_64-linux-gnu',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -790,35 +787,40 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python39/work/Python-3.9.14 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7:/pkg/lib:/pkg/lib/nss:/pkg/lib/nspr '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python39/work/Python-3.9.14 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7:/pkg/lib:/pkg/lib/nss:/pkg/lib/nspr '
                './python ./Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.9',
+ 'VERSION': '3.10',
+ 'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/pkgsrc/lang/python39/work/Python-3.9.14',
- 'abs_srcdir': '/usr/pkgsrc/lang/python39/work/Python-3.9.14',
- 'datarootdir': '/usr/pkg/share',
- 'exec_prefix': '/usr/pkg',
- 'prefix': '/usr/pkg',
+ 'abs_builddir': '/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7',
+ 'abs_srcdir': '/sda3/jails/current/pkglinux-pkgsrc.2022Q3/lang/python310/work/Python-3.10.7',
+ 'datarootdir': '/2022Q3/share',
+ 'exec_prefix': '/2022Q3',
+ 'prefix': '/2022Q3',
  'srcdir': '.'}
