@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.9
+#!/2022Q3/bin/python3.10
 
 """Python interface for the 'lsprof' profiler.
    Compatible with the 'profile' module.
@@ -7,7 +7,6 @@
 __all__ = ["run", "runctx", "Profile"]
 
 import _lsprof
-import io
 import profile as _pyprofile
 
 # ____________________________________________________________
@@ -168,7 +167,7 @@ def main():
         else:
             progname = args[0]
             sys.path.insert(0, os.path.dirname(progname))
-            with io.open_code(progname) as fp:
+            with open(progname, 'rb') as fp:
                 code = compile(fp.read(), progname, 'exec')
             globs = {
                 '__file__': progname,
