@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.9
+#!/2022Q3/bin/python3.10
 
 """Tool for measuring execution time of small code snippets.
 
@@ -72,6 +72,7 @@ def inner(_it, _timer{init}):
     _t0 = _timer()
     for _i in _it:
         {stmt}
+        pass
     _t1 = _timer()
     return _t1 - _t0
 """
