@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.9
+#!/2022Q3/bin/python3.10
 
 # Copyright 1994 by Lance Ellinghouse
 # Cathedral City, California Republic, United States of America.
@@ -130,14 +130,7 @@ def decode(in_file, out_file=None, mode=None, quiet=False):
             # If the filename isn't ASCII, what's up with that?!?
             out_file = hdrfields[2].rstrip(b' \t\r\n\f').decode("ascii")
             if os.path.exists(out_file):
-                raise Error(f'Cannot overwrite existing file: {out_file}')
-            if (out_file.startswith(os.sep) or
-                f'..{os.sep}' in out_file or (
-                    os.altsep and
-                    (out_file.startswith(os.altsep) or
-                     f'..{os.altsep}' in out_file))
-               ):
-                raise Error(f'Refusing to write to {out_file} due to directory traversal')
+                raise Error('Cannot overwrite existing file: %s' % out_file)
         if mode is None:
             mode = int(hdrfields[1], 8)
         #
